==> zreact-0.1.1.tgz: package/CHANGELOG.md <==
<a name="0.1.1"></a>
## [0.1.1](https://github.com/zeromake/zreact/compare/v0.1.0...v0.1.1) (2017-09-21)


### Bug Fixes

* **vnode:** vnode change class ([855ebb5](https://github.com/zeromake/zreact/commit/855ebb5))
* compat renderSubtreeIntoContainer error ([b547a3b](https://github.com/zeromake/zreact/commit/b547a3b))


### Features

* add compat ([56a188c](https://github.com/zeromake/zreact/commit/56a188c))



<a name="0.1.0"></a>
# [0.1.0](https://github.com/zeromake/zreact/compare/0.1.0...v0.1.0) (2017-09-08)


### Bug Fixes

* del devtools ([6ae3797](https://github.com/zeromake/zreact/commit/6ae3797))
* update api on d.ts ([cd3bfdb](https://github.com/zeromake/zreact/commit/cd3bfdb))
* update package and rollup config ([ab19d75](https://github.com/zeromake/zreact/commit/ab19d75))
* **vdom:** Text key, children set undefined ([f1bd5d3](https://github.com/zeromake/zreact/commit/f1bd5d3))


### Features

* add version ([22324be](https://github.com/zeromake/zreact/commit/22324be))
* add vnode event bind this ([5a79412](https://github.com/zeromake/zreact/commit/5a79412))
* render api change ([342efaa](https://github.com/zeromake/zreact/commit/342efaa))
* **component:** add like vue's vm.$emit function ([3a61707](https://github.com/zeromake/zreact/commit/3a61707))
* **event:** filter event not is component ([07e65f9](https://github.com/zeromake/zreact/commit/07e65f9))



<a name="0.0.4"></a>
## [0.0.4](https://github.com/zeromake/zreact/compare/v0.0.3...v0.0.4) (2017-08-17)


### Bug Fixes

* class change on interface ([cb1eb89](https://github.com/zeromake/zreact/commit/cb1eb89))
* render initDevTools add scheduling ([e8568d6](https://github.com/zeromake/zreact/commit/e8568d6))
* scheduling change defer ([7bbebb7](https://github.com/zeromake/zreact/commit/7bbebb7))
* update package; test error; dev_tools init change ([eea0856](https://github.com/zeromake/zreact/commit/eea0856))
* zreact.d.ts and package update ([c5d7237](https://github.com/zeromake/zreact/commit/c5d7237))



<a name="0.0.3"></a>
## [0.0.3](https://github.com/zeromake/zreact/compare/v0.0.2...v0.0.3) (2017-08-09)


### Bug Fixes

* component unmount children not clear ([46639fa](https://github.com/zeromake/zreact/commit/46639fa))
* server render not document ([e4fcbb5](https://github.com/zeromake/zreact/commit/e4fcbb5))


### Features

* add fiber ([9f85010](https://github.com/zeromake/zreact/commit/9f85010))
* add fiber demo ([59aaf1a](https://github.com/zeromake/zreact/commit/59aaf1a))



<a name="0.0.2"></a>
## [0.0.2](https://github.com/zeromake/zreact/compare/v0.0.1...v0.0.2) (2017-08-03)


### Bug Fixes

* add Annotations ([1ca7126](https://github.com/zeromake/zreact/commit/1ca7126))
* add context on dom patch ([19c0640](https://github.com/zeromake/zreact/commit/19c0640))
* child.base lost ([ca1fd8c](https://github.com/zeromake/zreact/commit/ca1fd8c))
* **typescript:** generate ([b1bf9fb](https://github.com/zeromake/zreact/commit/b1bf9fb))
* **typescript:** package typings ([e62a453](https://github.com/zeromake/zreact/commit/e62a453))
* delete docs ([4c7b868](https://github.com/zeromake/zreact/commit/4c7b868))
* package file home add ([5ce4a52](https://github.com/zeromake/zreact/commit/5ce4a52))
* up Annotations ([6a32ed4](https://github.com/zeromake/zreact/commit/6a32ed4))
* up Annotations ([2a78b36](https://github.com/zeromake/zreact/commit/2a78b36))


### Features

* add typescript type ([ae206d3](https://github.com/zeromake/zreact/commit/ae206d3))
* **devtools:** add devtools.js ([2bb5585](https://github.com/zeromake/zreact/commit/2bb5585))
* **docs:** add docs ([8223280](https://github.com/zeromake/zreact/commit/8223280))
* **tag:** v0.0.1 changlog ([cec803b](https://github.com/zeromake/zreact/commit/cec803b))
* **vdom:** add VDom context replace dom context ([aac1783](https://github.com/zeromake/zreact/commit/aac1783))
* build v0.0.2 ([43afdae](https://github.com/zeromake/zreact/commit/43afdae))
* package cmd ([3e991e3](https://github.com/zeromake/zreact/commit/3e991e3))



<a name="0.0.1"></a>
## [0.0.1](https://github.com/zeromake/zreact/compare/afddb4c...v0.0.1) (2017-07-24)


### Bug Fixes

* Component lost code ([b6c187d](https://github.com/zeromake/zreact/commit/b6c187d))
* **vdom:** domChild attr no clear ([cac0c49](https://github.com/zeromake/zreact/commit/cac0c49))
* copy code ok ([d482619](https://github.com/zeromake/zreact/commit/d482619))
* global child,component replace not unmount ([5f94e0e](https://github.com/zeromake/zreact/commit/5f94e0e))
* ie8 test ([b391d04](https://github.com/zeromake/zreact/commit/b391d04))
* render no exprot and html test ([133af07](https://github.com/zeromake/zreact/commit/133af07))
* rollup build ([ac2cae3](https://github.com/zeromake/zreact/commit/ac2cae3))
* **vdom:** childNodes no sync; class not set svg; capture error ([70a23c8](https://github.com/zeromake/zreact/commit/70a23c8))
* **vdom:** idiff child no sync dom error ([db306ca](https://github.com/zeromake/zreact/commit/db306ca))
* **vdom:** isSameNodeType error ([acbe1c2](https://github.com/zeromake/zreact/commit/acbe1c2))
* **vdom:** render merge null unmount; innerDiffNode children no unmount ([6159bf3](https://github.com/zeromake/zreact/commit/6159bf3))
* **vdom:** unmount domChild children cause removeNode error ([4ec1c67](https://github.com/zeromake/zreact/commit/4ec1c67))


### Features

* **config:** add ts rollup config file ([afddb4c](https://github.com/zeromake/zreact/commit/afddb4c))
* **src:** add createElement ([dbe3811](https://github.com/zeromake/zreact/commit/dbe3811))
* add changelog ([69e0231](https://github.com/zeromake/zreact/commit/69e0231))
* add CHANGELOG.md file ([73939e6](https://github.com/zeromake/zreact/commit/73939e6))

==> zreact-0.1.2.tgz: package/CHANGELOG.md <==
<a name="0.1.2"></a>
## [0.1.2](https://github.com/zeromake/zreact/compare/v0.1.1...v0.1.2) (2017-10-03)


### Bug Fixes

* componentWillUnmount triggered ([11fd90f](https://github.com/zeromake/zreact/commit/11fd90f))
* componentWillUnmount triggered on dom unmout after ([5e9d1a2](https://github.com/zeromake/zreact/commit/5e9d1a2))


### Features

* add ci and coverage ([5b57703](https://github.com/zeromake/zreact/commit/5b57703))



<a name="0.1.1"></a>
## [0.1.1](https://github.com/zeromake/zreact/compare/v0.1.0...v0.1.1) (2017-09-21)


### Bug Fixes

* **vnode:** vnode change class ([855ebb5](https://github.com/zeromake/zreact/commit/855ebb5))
* compat renderSubtreeIntoContainer error ([b547a3b](https://github.com/zeromake/zreact/commit/b547a3b))


### Features

* add compat ([56a188c](https://github.com/zeromake/zreact/commit/56a188c))



<a name="0.1.0"></a>
# [0.1.0](https://github.com/zeromake/zreact/compare/v0.0.4...v0.1.0) (2017-09-08)


### Bug Fixes

* del devtools ([6ae3797](https://github.com/zeromake/zreact/commit/6ae3797))
* update api on d.ts ([cd3bfdb](https://github.com/zeromake/zreact/commit/cd3bfdb))
* update package and rollup config ([ab19d75](https://github.com/zeromake/zreact/commit/ab19d75))
* **vdom:** Text key, children set undefined ([f1bd5d3](https://github.com/zeromake/zreact/commit/f1bd5d3))


### Features

* add version ([22324be](https://github.com/zeromake/zreact/commit/22324be))
* add vnode event bind this ([5a79412](https://github.com/zeromake/zreact/commit/5a79412))
* render api change ([342efaa](https://github.com/zeromake/zreact/commit/342efaa))
* **component:** add like vue's vm.$emit function ([3a61707](https://github.com/zeromake/zreact/commit/3a61707))
* **event:** filter event not is component ([07e65f9](https://github.com/zeromake/zreact/commit/07e65f9))



<a name="0.0.4"></a>
## [0.0.4](https://github.com/zeromake/zreact/compare/v0.0.3...v0.0.4) (2017-08-17)


### Bug Fixes

* class change on interface ([cb1eb89](https://github.com/zeromake/zreact/commit/cb1eb89))
* render initDevTools add scheduling ([e8568d6](https://github.com/zeromake/zreact/commit/e8568d6))
* scheduling change defer ([7bbebb7](https://github.com/zeromake/zreact/commit/7bbebb7))
* update package; test error; dev_tools init change ([eea0856](https://github.com/zeromake/zreact/commit/eea0856))
* zreact.d.ts and package update ([c5d7237](https://github.com/zeromake/zreact/commit/c5d7237))



<a name="0.0.3"></a>
## [0.0.3](https://github.com/zeromake/zreact/compare/v0.0.2...v0.0.3) (2017-08-09)


### Bug Fixes

* component unmount children not clear ([46639fa](https://github.com/zeromake/zreact/commit/46639fa))
* server render not document ([e4fcbb5](https://github.com/zeromake/zreact/commit/e4fcbb5))


### Features

* add fiber ([9f85010](https://github.com/zeromake/zreact/commit/9f85010))
* add fiber demo ([59aaf1a](https://github.com/zeromake/zreact/commit/59aaf1a))



<a name="0.0.2"></a>
## [0.0.2](https://github.com/zeromake/zreact/compare/v0.0.1...v0.0.2) (2017-08-03)


### Bug Fixes

* add Annotations ([1ca7126](https://github.com/zeromake/zreact/commit/1ca7126))
* add context on dom patch ([19c0640](https://github.com/zeromake/zreact/commit/19c0640))
* child.base lost ([ca1fd8c](https://github.com/zeromake/zreact/commit/ca1fd8c))
* **typescript:** generate ([b1bf9fb](https://github.com/zeromake/zreact/commit/b1bf9fb))
* **typescript:** package typings ([e62a453](https://github.com/zeromake/zreact/commit/e62a453))
* delete docs ([4c7b868](https://github.com/zeromake/zreact/commit/4c7b868))
* package file home add ([5ce4a52](https://github.com/zeromake/zreact/commit/5ce4a52))
* up Annotations ([6a32ed4](https://github.com/zeromake/zreact/commit/6a32ed4))
* up Annotations ([2a78b36](https://github.com/zeromake/zreact/commit/2a78b36))


### Features

* add typescript type ([ae206d3](https://github.com/zeromake/zreact/commit/ae206d3))
* **devtools:** add devtools.js ([2bb5585](https://github.com/zeromake/zreact/commit/2bb5585))
* **docs:** add docs ([8223280](https://github.com/zeromake/zreact/commit/8223280))
* **tag:** v0.0.1 changlog ([cec803b](https://github.com/zeromake/zreact/commit/cec803b))
* **vdom:** add VDom context replace dom context ([aac1783](https://github.com/zeromake/zreact/commit/aac1783))
* build v0.0.2 ([43afdae](https://github.com/zeromake/zreact/commit/43afdae))
* package cmd ([3e991e3](https://github.com/zeromake/zreact/commit/3e991e3))



<a name="0.0.1"></a>
## [0.0.1](https://github.com/zeromake/zreact/compare/afddb4c...v0.0.1) (2017-07-24)


### Bug Fixes

* Component lost code ([b6c187d](https://github.com/zeromake/zreact/commit/b6c187d))
* **vdom:** domChild attr no clear ([cac0c49](https://github.com/zeromake/zreact/commit/cac0c49))
* copy code ok ([d482619](https://github.com/zeromake/zreact/commit/d482619))
* global child,component replace not unmount ([5f94e0e](https://github.com/zeromake/zreact/commit/5f94e0e))
* ie8 test ([b391d04](https://github.com/zeromake/zreact/commit/b391d04))
* render no exprot and html test ([133af07](https://github.com/zeromake/zreact/commit/133af07))
* rollup build ([ac2cae3](https://github.com/zeromake/zreact/commit/ac2cae3))
* **vdom:** childNodes no sync; class not set svg; capture error ([70a23c8](https://github.com/zeromake/zreact/commit/70a23c8))
* **vdom:** idiff child no sync dom error ([db306ca](https://github.com/zeromake/zreact/commit/db306ca))
* **vdom:** isSameNodeType error ([acbe1c2](https://github.com/zeromake/zreact/commit/acbe1c2))
* **vdom:** render merge null unmount; innerDiffNode children no unmount ([6159bf3](https://github.com/zeromake/zreact/commit/6159bf3))
* **vdom:** unmount domChild children cause removeNode error ([4ec1c67](https://github.com/zeromake/zreact/commit/4ec1c67))


### Features

* **config:** add ts rollup config file ([afddb4c](https://github.com/zeromake/zreact/commit/afddb4c))
* **src:** add createElement ([dbe3811](https://github.com/zeromake/zreact/commit/dbe3811))
* add changelog ([69e0231](https://github.com/zeromake/zreact/commit/69e0231))
* add CHANGELOG.md file ([73939e6](https://github.com/zeromake/zreact/commit/73939e6))
